Syntax for creating myspace data with STATE and LOCAL/CITY codes
Cleaned up for ease of reading and replication
3/19/2008, Eric Rogers

Here's a summary of what I did, in the following state syntax:

STATE
1.Recomputed the state names in the MySpace file to remove the leading blank spaces before each one.
2.Created another code file, state-fips-crosswalk.sav, that added state FIPS codes and abbreviations, merging by the "State" variable where the user had entered:
	a.The full and correctly-spelled state name only;
	b.The full and correct state postal abbreviation only; or
	c."DISTRICT OF" in place of the full "DISTRICT OF COLUMBIA", to fix some kind of truncation problem that resulted in dropping almost all DC cases without this step.
3.Merged the myspace file with this code file.

CITY
1.Edited city/locality code file (derived from tncnpc40.save, from FAUI data site) to remove US/international prefix; also made a couple of minor corrections.
2.Concatenated city+stateabbreviation into standard format in the myspace file.
3.Merged these two files, so that any matching [CITY, ST] combination was assigned the appropriate city code.

The final result is that 2,411,967 cases now have state abbreviations and FIPS codes assigned to them.  A subset of this (1,321,302 cases) have successfully been
assigned local codes.  Those codes are of the format (S)SLLL.LL, where the S stand for state FIPS codes (only one digit if the leading digit would be a zero) and 
the L stand for local/city codes.

RELEVANT FILES:
CompleteMySpaceData-city.sav:  myspace data file with state and city codes.
locid-frequencies.xls: output of frequencies analysis of LOCID variable in merge file.
us-placecodes.sav:  code source file, derived from tncnpc40.sav via steps documented in syntax.
state-fips-crosswalk.sav:  File I created to contain state abbreviations and FIPS codes, keyed by state name (plus abbreviationsas explained in syntax).
myspace-summary.sps:  Cleaned up and commented version of my syntax for adding state and city codes.


*********
FIRST, merging in the STATE codes:

***
*Sorting MySpace file ascending by "State"

SORT CASES BY
  State (A) .

*Saving in a new file for just the STATE merge:

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-state.sav'
 /COMPRESSED.

*Open state FIPS crosswalk:

GET
  FILE='Z:\Documents\Scenes\Data\MySpaceBandData\state-fips-crosswalk.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*Sort it:

SORT CASES BY
  State (A) .

*Save it:

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\state-fips'+
 '-crosswalk.sav'
 /COMPRESSED.

*Closing state code file, leaving just myspace file open.
*"State" var in MySpace file has leading spaces.  Need to try to remove those.
*First, renaming var "State" to "StateOld".  And manually creating new "State" var with same space and length attributes.
*Then, LTRIM:

COMPUTE State = LTRIM(StateOld) .
EXECUTE .

*Manually deleting variable "StateOld" now, then re-sorting on "State" just to be sure.  Then saving.

SORT CASES BY
  State (A) .

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-state.sav'
 /COMPRESSED.

*NOW attempting to merge with source file including:  state names, correction for DC problem (see log), and state abbrevs:

MATCH FILES /FILE=*
 /TABLE='Z:\Documents\Scenes\Data\MySpaceBandData\state-fips-crosswalk.sav'
 /BY State.
EXECUTE.

*And checking if it worked by running frequencies on one of the added vars:

FREQUENCIES
  VARIABLES=STATEABB
  /ORDER=  ANALYSIS .

*Doing a quick visual inspection...looks good.  

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-state.sav'
 /COMPRESSED.




*************************************
NOW, turning to CITY codes...
*************************************
*3/11/08:  Got FAUI place codes from TNC.  

GET
  FILE='/Users/erogers/Documents/Scenes/Data/MySpaceBandData/tncnpc40.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*Sorting by INTLID:

SORT CASES BY intlid(A).

*Manually deleting all NON-US cases, for simplicity.
*and then saving as new file:

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/MySpaceBandData/us-placecodes.sav'
  /COMPRESSED.

*Also manually removing all the extraneous variables, so just have place codes/names.  And saving again.

*Now need to remove the international part of the ID code.  Should be able to do that by subtracting 100000 from INTLID.

COMPUTE LOCID=intlid-100000.
EXECUTE.

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\us-placecodes.sav'
 /COMPRESSED.

*3/18/08:  Manually checking state codes against a FIPS state list obtained from NIST.  State codes check out.  Noticed these errors/issues, though:
*DOUGLAS, AZ                        	5008.00  Should be 4008, for Arizona, not Arkansas.
*COLLEGE PARK, PA                   	24022.00 Clearly state abbreviation should be MD.
*CHEYENNE00&0000000&0000000&0000    	56005.00 Should be, WY.
*NASHVILLE-DAVIDSON, TN             	47101.60 Technically a correct name, but if we search for the whole hyphenated thing, well miss everything.  Shortening to just Nashville.
*Fixed these manually.*

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\us-placecodes.sav'
 /COMPRESSED.
**********************************

*Now, open CompleteMySpaceData-state.sav.  See the syntax included with that file if you want to know how state codes and abbreviations were added to the data.

**********************************
*Next step:  try to add in city data, too.
*Save into a new myspace file for this purpose:

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-city.sav'
 /COMPRESSED.

*Create a new variable to be the key shared with codes from tncnpc40:  "intlname".

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-city.sav'
 /COMPRESSED.

**Now, concatenating:

COMPUTE intlname = CONCAT(rtrim(ltrim(city)),", ",rtrim(ltrim(STATEABB))).
EXECUTE.

*Doing a quick visual inspection of data...looks like it worked as intended.

SAVE OUTFILE='Z:\Documents\Scenes\Data\MySpaceBandData\CompleteMySpaceData'+
 '-city.sav'
 /COMPRESSED.

*Sorting both data files ascending by intlname, saving.

SORT CASES BY
  intlname (A) .

*NOW attempting the merge...

MATCH FILES /FILE=*
 /TABLE='Z:\Documents\Scenes\Data\MySpaceBandData\us-placecodes.sav'
 /RENAME (intlid = d0)
 /BY intlname
 /DROP= d0.
EXECUTE.

*Looks like it worked, on visual inspection, so saving the result.
*Then running frequencies on LOCID to get a sense of what we've got...

FREQUENCIES
  VARIABLES=LOCID
  /ORDER=  ANALYSIS .

******************************
So this final file has STATE codes for
